==> kdevelop-php-22.08.3-1-aarch64.pkg.tar.xz: usr/include/kdev-php/private/5.7/parser/phpast-fwd.h <==
// WARNING! All changes made in this file will be lost!

#ifndef PHP_AST_FWD_INCLUDED
#define PHP_AST_FWD_INCLUDED

#include "parserexport.h"
namespace Php
{

struct  AstNode;
struct AdditiveExpressionAst;
struct AdditiveExpressionRestAst;
struct ArrayIndexSpecifierAst;
struct ArrayPairValueAst;
struct AssignmentExpressionAst;
struct AssignmentExpressionCheckIfVariableAst;
struct AssignmentExpressionEqualAst;
struct AssignmentListAst;
struct AssignmentListElementAst;
struct BaseVariableAst;
struct BaseVariableWithFunctionCallsAst;
struct BitAndExpressionAst;
struct BitOrExpressionAst;
struct BitXorExpressionAst;
struct BooleanAndExpressionAst;
struct BooleanOrExpressionAst;
struct CaseListAst;
struct Case_itemAst;
struct CatchItemAst;
struct ClassBodyAst;
struct ClassConstantAst;
struct ClassConstantDeclarationAst;
struct ClassDeclarationStatementAst;
struct ClassExtendsAst;
struct ClassImplementsAst;
struct ClassNameAst;
struct ClassNameReferenceAst;
struct ClassPropertyAst;
struct ClassStatementAst;
struct ClassVariableAst;
struct ClassVariableDeclarationAst;
struct ClosureAst;
struct CommonScalarAst;
struct CompoundVariableAst;
struct CompoundVariableWithSimpleIndirectReferenceAst;
struct ConditionalExpressionAst;
struct ConstantDeclarationAst;
struct ConstantOrClassConstAst;
struct CtorArgumentsAst;
struct DeclareItemAst;
struct DeclareStatementAst;
struct DimListItemAst;
struct ElseSingleAst;
struct ElseifListAst;
struct ElseifListItemAst;
struct EncapsAst;
struct EncapsListAst;
struct EncapsVarAst;
struct EncapsVarOffsetAst;
struct EqualityExpressionAst;
struct EqualityExpressionRestAst;
struct ExprAst;
struct ForExprAst;
struct ForStatementAst;
struct ForeachStatementAst;
struct ForeachVariableAst;
struct FunctionCallAst;
struct FunctionCallParameterListAst;
struct FunctionCallParameterListElementAst;
struct FunctionDeclarationStatementAst;
struct GenericTypeHintAst;
struct GlobalVarAst;
struct IdentifierAst;
struct IifeSyntaxAst;
struct InnerStatementListAst;
struct InstantiationAccessAst;
struct InterfaceDeclarationStatementAst;
struct LexicalVarAst;
struct LexicalVarListAst;
struct LogicalAndExpressionAst;
struct LogicalOrExpressionAst;
struct LogicalXorExpressionAst;
struct MethodBodyAst;
struct MultiplicativeExpressionAst;
struct MultiplicativeExpressionRestAst;
struct NamespaceDeclarationStatementAst;
struct NamespacedIdentifierAst;
struct NewElseSingleAst;
struct NewElseifListAst;
struct NewelseifListItemAst;
struct NullCoalesceExpressionAst;
struct ObjectDimListAst;
struct ObjectOperatorAst;
struct ObjectPropertyAst;
struct OptionalClassModifierAst;
struct OptionalModifiersAst;
struct OuterTopStatementAst;
struct ParameterAst;
struct ParameterListAst;
struct ParameterTypeAst;
struct PostprefixOperatorAst;
struct PrintExpressionAst;
struct PropertyTypeAst;
struct PropertyTypeHintAst;
struct RelationalExpressionAst;
struct RelationalExpressionRestAst;
struct ReservedNonModifierIdentifierAst;
struct ReservedNonModifiersAst;
struct ReturnTypeAst;
struct ScalarAst;
struct SemiReservedAst;
struct SemiReservedIdentifierAst;
struct SemicolonOrCloseTagAst;
struct ShiftExpressionAst;
struct ShiftExpressionRestAst;
struct StartAst;
struct StatementAst;
struct StaticArrayPairValueAst;
struct StaticMemberAst;
struct StaticPropertyAst;
struct StaticScalarAst;
struct StaticVarAst;
struct StringIndexSpecifierAst;
struct SwitchCaseListAst;
struct TopStatementAst;
struct TraitAliasDeclarationAst;
struct TraitAliasIdentifierAst;
struct TraitAliasStatementAst;
struct TraitDeclarationStatementAst;
struct TraitVisibilityModifiersAst;
struct UnaryExpressionAst;
struct UnaryExpressionNotPlusminusAst;
struct UseNamespaceAst;
struct UseStatementAst;
struct VarExpressionAst;
struct VarExpressionArrayAst;
struct VarExpressionNewObjectAst;
struct VarExpressionNormalAst;
struct VariableAst;
struct VariableIdentifierAst;
struct VariableNameAst;
struct VariableObjectPropertyAst;
struct VariablePropertyAst;
struct VariableWithoutObjectsAst;
struct WhileStatementAst;

} // end of namespace Php

#endif

==> kdevelop-php-23.08.5-1-aarch64.pkg.tar.xz: usr/include/kdev-php/private/5.7/parser/phpast-fwd.h <==
// WARNING! All changes made in this file will be lost!

#ifndef PHP_AST_FWD_INCLUDED
#define PHP_AST_FWD_INCLUDED

#include "parserexport.h"
namespace Php
{

struct  AstNode;
struct AdditiveExpressionAst;
struct AdditiveExpressionRestAst;
struct ArrayIndexSpecifierAst;
struct ArrayPairValueAst;
struct AssignmentExpressionAst;
struct AssignmentExpressionCheckIfVariableAst;
struct AssignmentExpressionEqualAst;
struct AssignmentListAst;
struct AssignmentListElementAst;
struct BaseVariableAst;
struct BaseVariableWithFunctionCallsAst;
struct BitAndExpressionAst;
struct BitOrExpressionAst;
struct BitXorExpressionAst;
struct BooleanAndExpressionAst;
struct BooleanOrExpressionAst;
struct CaseListAst;
struct Case_itemAst;
struct CatchItemAst;
struct ClassBodyAst;
struct ClassConstantAst;
struct ClassConstantDeclarationAst;
struct ClassDeclarationStatementAst;
struct ClassExtendsAst;
struct ClassImplementsAst;
struct ClassNameAst;
struct ClassNameReferenceAst;
struct ClassPropertyAst;
struct ClassStatementAst;
struct ClassVariableAst;
struct ClassVariableDeclarationAst;
struct ClosureAst;
struct CommonScalarAst;
struct CompoundNamespaceAst;
struct CompoundNamespaceStatementAst;
struct CompoundVariableAst;
struct CompoundVariableWithSimpleIndirectReferenceAst;
struct ConditionalExpressionAst;
struct ConstantDeclarationAst;
struct ConstantOrClassConstAst;
struct CtorArgumentsAst;
struct DeclareItemAst;
struct DeclareStatementAst;
struct DimListItemAst;
struct ElseSingleAst;
struct ElseifListAst;
struct ElseifListItemAst;
struct EncapsAst;
struct EncapsListAst;
struct EncapsVarAst;
struct EncapsVarOffsetAst;
struct EqualityExpressionAst;
struct EqualityExpressionRestAst;
struct ExprAst;
struct ForExprAst;
struct ForStatementAst;
struct ForeachStatementAst;
struct ForeachVariableAst;
struct FunctionCallAst;
struct FunctionCallParameterListAst;
struct FunctionCallParameterListElementAst;
struct FunctionDeclarationStatementAst;
struct GenericTypeHintAst;
struct GlobalVarAst;
struct IdentifierAst;
struct IifeSyntaxAst;
struct InnerStatementListAst;
struct InnerUseNamespaceAst;
struct InstantiationAccessAst;
struct InterfaceDeclarationStatementAst;
struct LexicalVarAst;
struct LexicalVarListAst;
struct LogicalAndExpressionAst;
struct LogicalOrExpressionAst;
struct LogicalXorExpressionAst;
struct MethodBodyAst;
struct MultiplicativeExpressionAst;
struct MultiplicativeExpressionRestAst;
struct NamespaceDeclarationStatementAst;
struct NamespacedIdentifierAst;
struct NamespacedIdentifierBeforeGroupedNamespaceAst;
struct NewElseSingleAst;
struct NewElseifListAst;
struct NewelseifListItemAst;
struct NullCoalesceExpressionAst;
struct ObjectDimListAst;
struct ObjectOperatorAst;
struct ObjectPropertyAst;
struct OptionalClassModifierAst;
struct OptionalModifiersAst;
struct OuterTopStatementAst;
struct ParameterAst;
struct ParameterListAst;
struct ParameterTypeAst;
struct PostprefixOperatorAst;
struct PrintExpressionAst;
struct PropertyTypeAst;
struct PropertyTypeHintAst;
struct RelationalExpressionAst;
struct RelationalExpressionRestAst;
struct ReservedNonModifierIdentifierAst;
struct ReservedNonModifiersAst;
struct ReturnTypeAst;
struct ScalarAst;
struct SemiReservedAst;
struct SemiReservedIdentifierAst;
struct SemicolonOrCloseTagAst;
struct ShiftExpressionAst;
struct ShiftExpressionRestAst;
struct StartAst;
struct StatementAst;
struct StaticArrayPairValueAst;
struct StaticMemberAst;
struct StaticPropertyAst;
struct StaticScalarAst;
struct StaticVarAst;
struct StringIndexSpecifierAst;
struct SwitchCaseListAst;
struct TopStatementAst;
struct TraitAliasDeclarationAst;
struct TraitAliasIdentifierAst;
struct TraitAliasStatementAst;
struct TraitDeclarationStatementAst;
struct TraitVisibilityModifiersAst;
struct UnaryExpressionAst;
struct UnaryExpressionNotPlusminusAst;
struct UseNamespaceOrUseGroupedNamespaceAst;
struct UseStatementAst;
struct VarExpressionAst;
struct VarExpressionArrayAst;
struct VarExpressionNewObjectAst;
struct VarExpressionNormalAst;
struct VariableAst;
struct VariableIdentifierAst;
struct VariableNameAst;
struct VariableObjectPropertyAst;
struct VariablePropertyAst;
struct VariableWithoutObjectsAst;
struct WhileStatementAst;

} // end of namespace Php

#endif
